@@ -222,71 +222,49 @@ class tentext:
             print(study.get_best_result())
 
         
-class loadmodel(textgen):
-    def __init__(self, modelname):
-        self.model = modelname
 
 
-    def loadmodel(self, modelname):
-        self.loadmodel = keras.models.load_model(modelname)
-        return self.loadmodel
-
-    def sequence(self, corpus, padding_method):
-        '''Tokenizes the data and turns the tokens into sequences'''
-        padding_method = padding_method
-        #print('Tokenizing your data', '-------'*7)
-        tokenizer.fit_on_texts(corpus)
-        totalWords = len(tokenizer.word_index) + 1
-        sequences = []
-        #print('padding sequence', '-------'*7)
-        for line in corpus:
-            tokenList = tokenizer.texts_to_sequences([line])[0]
-            for i in range(1, len(tokenList)):
-                ngramSequence = tokenList[:i+1]
-                sequences.append(ngramSequence)
-            #self.sequences = sequences
-            totalwords = totalWords
-            #print(totalWords)
-            #print(self.sequences)
-            '''Gives the sequences a uniform length by padding them'''
+def load_model_predict(corpus, padding_method, modelname, word_length, sample_text):
+    model = keras.models.load_model(modelname, compile=False)
+    '''Tokenizes the data and turns the tokens into sequences'''
+    padding_method = padding_method
+    #print('Tokenizing your data', '-------'*7)
+    tokenizer.fit_on_texts(corpus)
+    totalWords = len(tokenizer.word_index) + 1
+    sequences = []
+    #print('padding sequence', '-------'*7)
+    for line in corpus:
+        tokenList = tokenizer.texts_to_sequences([line])[0]
+        for i in range(1, len(tokenList)):
+            ngramSequence = tokenList[:i+1]
+            sequences.append(ngramSequence)
+    #self.sequences = sequences
+    totalwords = totalWords
+    #print(totalWords)
+    #print(self.sequences)
+    '''Gives the sequences a uniform length by padding them'''
     
-        maxSequenceLen = max([len(seq) for seq in sequences])
-        _sequences = np.array(pad_sequences(sequences, maxlen=maxSequenceLen, padding=padding_method))
-        predictors, label = _sequences[:,:-1], _sequences[:,-1]
-        _label = to_categorical(label, num_classes=totalwords)
-        #print(totalWords)
-        #print(sequences[:5])
-        return self.predictors, self._label, self.maxSequenceLen, self.totalwords
-
-    def predict(self, sample_text, word_length, segment, verbose):               #A text seed is provided
+    maxSequenceLen = max([len(seq) for seq in sequences])
+    _sequences = np.array(pad_sequences(sequences, maxlen=maxSequenceLen, padding=padding_method))
     
-        '''Predicts the next text sequences'''
-        #model = self.model    
+    predictors, label = _sequences[:,:-1], _sequences[:,-1]
+    _label = to_categorical(label, num_classes=totalwords)
+    #print(totalWords)
+    #print(sequences[:5])
+    def generateText(seed):
         for wordLength in range(word_length):   #Generates a text with a range of word length
-            tokenList = self.tokenizer.texts_to_sequences([sample_text])[0]  #Turns the seed into sequences
-            tokenList = pad_sequences([tokenList], maxlen=self.maxSequenceLen - 1, padding=padding_method)
-            predicted = self.model.predict_classes(tokenList, verbose=verbose) #Predicts the next sequence(generated
+            tokenList = tokenizer.texts_to_sequences([seed])[0]  #Turns the seed into sequences
+            tokenList = pad_sequences([tokenList], maxlen=maxSequenceLen - 1, padding='pre')
+            predicted = model.predict_classes(tokenList, verbose=0) #Predicts the next sequence(generated
             outputWord = " "                                         #text)  
-            for word, index in self.tokenizer.word_index.items():
+            for word, index in tokenizer.word_index.items():
                 if index == predicted:
                     outputWord = word
                     break
-            sample_text += " " + outputWord
-            #Returns the seed plus generated text
-        self.sample_text = sample_text
-        if segment == True:
-            segmenter = DeepSegment('en')
-            result = segmenter.segment(self.sample_text)
-            sample_text = result
-        else:
-            print(sample_text)
-            sample_text = self.sample_text
-        return sample_text
-
-        
-
-
-
+            seed += " " + outputWord     #Returns the seed plus generated text
+        return seed
+    ree = generateText(seed = sample_text)
+    return ree
 
 
 
